[PATCH v2 22/34] staging: wilc1000: remove typedef from the struct tstrHostIfSetDrvHandler

Tony Cho tony.cho at atmel.com
Mon Sep 21 03:16:51 UTC 2015


This patch removes typedef from the struct tstrHostIfSetDrvHandler and
renames it to drv_handler in order to comply with the Linux coding
style.

Signed-off-by: Tony Cho <tony.cho at atmel.com>
---
 drivers/staging/wilc1000/host_interface.c | 7 ++++---
 drivers/staging/wilc1000/host_interface.h | 4 ++--
 2 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/drivers/staging/wilc1000/host_interface.h b/drivers/staging/wilc1000/host_interface.h
index b24eeb6..dc6fe73 100644
--- a/drivers/staging/wilc1000/host_interface.h
+++ b/drivers/staging/wilc1000/host_interface.h
@@ -255,9 +255,9 @@ typedef struct {
 	void *u32UserConnectPvoid;
 } tstrWILC_UsrConnReq;
 
-typedef struct {
+struct drv_handler {
 	u32 u32Address;
-} tstrHostIfSetDrvHandler;
+};
 
 typedef struct {
 	u32 u32Mode;
diff --git a/drivers/staging/wilc1000/host_interface.c b/drivers/staging/wilc1000/host_interface.c
index 689832a..9824b00 100644
--- a/drivers/staging/wilc1000/host_interface.c
+++ b/drivers/staging/wilc1000/host_interface.c
@@ -432,7 +432,7 @@ union message_body {
 	struct power_mgmt_param strPowerMgmtparam;     /*!< Power Management message body */
 	struct sta_inactive_t strHostIfStaInactiveT;
 	struct set_ip_addr strHostIfSetIP;
-	tstrHostIfSetDrvHandler strHostIfSetDrvHandler;
+	struct drv_handler strHostIfSetDrvHandler;
 	tstrHostIFSetMulti strHostIfSetMulti;
 	tstrHostIfSetOperationMode strHostIfSetOperationMode;
 	tstrHostIfSetMacAddress strHostIfSetMacAddress;
@@ -665,14 +665,15 @@ static s32 Handle_SetChannel(tstrWILC_WFIDrv *drvHandler,
 /**
  *  @brief Handle_SetWfiDrvHandler
  *  @details    Sending config packet to firmware to set driver handler
  *  @param[in]   void * drvHandler,tstrHostIfSetDrvHandler* pstrHostIfSetDrvHandler
  *  @return     Error code.
  *  @author
  *  @date
  *  @version	1.0
  */
 static s32 Handle_SetWfiDrvHandler(tstrWILC_WFIDrv *drvHandler,
-				   tstrHostIfSetDrvHandler *pstrHostIfSetDrvHandler)
+				   struct drv_handler *pstrHostIfSetDrvHandler)
 {
 
 	s32 s32Error = 0;
@@ -665,14 +665,15 @@ static s32 Handle_SetChannel(tstrWILC_WFIDrv *drvHandler,
  *  @brief Handle_SetWfiDrvHandler
  *  @details    Sending config packet to firmware to set driver handler
- *  @param[in]   void * drvHandler,tstrHostIfSetDrvHandler* pstrHostIfSetDrvHandler
+ *  @param[in]   void * drvHandler,
+ *		 struct drv_handler *pstrHostIfSetDrvHandler
  *  @return     Error code.
  *  @author
-- 
1.9.1



More information about the devel mailing list